# CognitiveGeo

![](https://github.com/geopyteam/cognitivegeo/blob/master/logo.png?raw=true)

[CognitiveGeo] is a Python tool for geoscientific data analysis (i.e., seismic).

### Dependency

CognitiveGeo uses a number of open source projects to work properly:

* [PyQt5] - GUIs
* [vispy] - Visualizations

### Installation

* pip install cognitivegeo

### Run

* import cognitivegeo as cgeo
* cgeo.gui.start()

### Development

Want to contribute? [Join us]

### License
GNU Affero General Public License v3 or later (AGPLv3+)

[//]: # (These are reference links used in the body of this note and get stripped out when the markdown processor does its job. There is no need to format nicely because it shouldn't be seen. Thanks SO - http://stackoverflow.com/questions/4823468/store-comments-in-markdown-syntax)


   [CognitiveGeo]: <https://geopyteam.wixsite.com/cognitivegeo>
   [PyQt5]: <https://pypi.org/project/PyQt5/>
   [vispy]: <https://pypi.org/project/vispy/>
   [Join us]: <https://geopyteam.wixsite.com/cognitivegeo>
